@@ -41,8 +41,8 @@ from xl import (
 
 from xl.nls import gettext as _
 
-from xlgui import cover, guiutil, main
-from xlgui.widgets import info, menu, dialogs, playback
+from xlgui import guiutil, main
+from xlgui.widgets import menu, dialogs, playback
 
 import previewprefs
 
@@ -86,7 +86,7 @@ class SecondaryOutputPlugin(object):
         # Initialize the player objects needed
         #
     
-        self.player = player.get_player()('preview_device')
+        self.player = player.get_player('preview_device')
         self.queue = player.queue.PlayQueue( self.player, 
                                              location=os.path.join(xdg.get_data_dir(), 'preview_device_queue.state'),
                                              name='Preview Device Queue')
@@ -117,15 +117,11 @@ class SecondaryOutputPlugin(object):
         self.pane = gtk.HPaned()
         
         # stolen from main
-        self.info_area = info.TrackInfoPane(self.player)
+        self.info_area = main.MainWindowTrackInfoPane(self.player)
         self.info_area.set_auto_update(True)
         self.info_area.set_padding(3, 3, 3, 3)
         self.info_area.hide_all()
         self.info_area.set_no_show_all(True)
-        
-        self.cover = cover.CoverWidget(self.info_area.cover_image, self.player)
-        self.cover.hide_all()
-        self.cover.set_no_show_all(True)
 
         volume_control = playback.VolumeControl(self.player)
         self.info_area.get_action_area().pack_start(volume_control)
@@ -133,7 +129,7 @@ class SecondaryOutputPlugin(object):
         self.playpause_button = gtk.Button()
         self.playpause_button.set_relief(gtk.RELIEF_NONE)
         self._on_playback_end(None, None, None)
-        self.playpause_button.connect('clicked', self._on_playpause_button_clicked)
+        self.playpause_button.connect('button-press-event', self._on_playpause_button_clicked)
         
         progress_bar = playback.SeekProgressBar(self.player, use_markers=False)
         
@@ -159,14 +155,13 @@ class SecondaryOutputPlugin(object):
             
         providers.register('menubar-view-menu', self.menu)
         
-        self.preview_menuitem = menu.simple_menu_item('preview', [], 
+        self.preview_menuitem = menu.simple_menu_item('_preview', ['enqueue'], 
                 _('Preview'), callback=self._on_preview,
-                condition_fn=lambda n,p,c: c['selection-count'] != 0)
+                condition_fn=lambda n,p,c: not c['selection-empty'])
         
         # TODO: Setup on other context menus
-        self.preview_provides = [ 'files-panel-context-menu',
-                                  'playlist-context-menu',
-                                  'collection-panel-context-menu' ]
+        self.preview_provides = [ 'track-panel-menu',
+                                  'playlist-context-menu']
         
         for provide in self.preview_provides:
             providers.register(provide, self.preview_menuitem)
@@ -291,19 +286,27 @@ class SecondaryOutputPlugin(object):
     def _on_preview(self, menu, display_name, playlist_view, context):
         self._init_gui_hooks()
         tracks = context['selected-tracks']
-        self.queue.play(tracks[0])
+        if len(tracks) > 0:
+            self.queue.play(tracks[0])
         
     
     #
     # Various player events
     #
     
-    def _on_playpause_button_clicked(self, *e):
+    def _on_playpause_button_clicked(self, widget, event):
         """
             Called when the play button is clicked
         """
-        if self.player.is_paused() or self.player.is_playing():
-            self.player.toggle_pause()
+        
+        if event.button == 1:
+            if event.type == gtk.gdk.BUTTON_PRESS and \
+                (self.player.is_paused() or self.player.is_playing()):
+                
+                self.player.toggle_pause()
+                
+            elif event.type == gtk.gdk._2BUTTON_PRESS:
+                self.player.stop()
         
         
     @guiutil.idle_add()
@@ -319,13 +322,14 @@ class SecondaryOutputPlugin(object):
                 self.info_area.hide_all()
             self.info_area.set_no_show_all(True)
             
-        elif option == 'gui/show_info_area_covers':        
-            self.cover.set_no_show_all(False)
+        elif option == 'gui/show_info_area_covers':
+            cover = self.info_area.cover     
+            cover.set_no_show_all(False)
             if settings.get_option(option, True):
-                self.cover.show_all()
+                cover.show_all()
             else:
-                self.cover.hide_all()
-            self.cover.set_no_show_all(True)
+                cover.hide_all()
+            cover.set_no_show_all(True)
 
     def _on_playback_resume(self, type, player, data):
         self.resuming = True
@@ -344,7 +348,7 @@ class SecondaryOutputPlugin(object):
         image = gtk.image_new_from_stock(gtk.STOCK_MEDIA_PAUSE, 
                                          gtk.ICON_SIZE_BUTTON)
         self.playpause_button.set_image(image)
-        self.playpause_button.set_tooltip_text( _('Pause Playback') )
+        self.playpause_button.set_tooltip_text( _('Pause Playback (double click to stop)') )
 
     @guiutil.idle_add()
     def _on_playback_end(self, type, player, object):
