@@ -28,4 +28,4 @@
 
 outpath=$(echo "$1" | sed "s/.po/\/LC_MESSAGES/")
 mkdir -p $outpath
-msgmerge -o - $1 messages.pot | msgfmt -c -o $outpath/exaile.mo -
+msgmerge -q -o - $1 messages.pot | msgfmt -c -o $outpath/exaile.mo -
