@@ -7,7 +7,7 @@ echo "Creating distribution for Exaile $DIST_VERSION"
 
 tar --gzip --format=posix --owner 0 --group 0 \
     -cf dist/exaile-${DIST_VERSION}.tar.gz dist/copy \
-    --exclude=dist/copy/.bzr* \
+    --exclude=dist/copy/.git* \
     --transform s/dist\\/copy/exaile-${DIST_VERSION}/
 
 gpg --armor --sign --detach-sig dist/exaile-${DIST_VERSION}.tar.gz
@@ -21,4 +21,4 @@ echo "Generating Windows installer via Wine+NSIS"
 wine "C:/Program Files (x86)/NSIS/makensis.exe" tools/win-installer/exaile_installer.nsi
 mv tools/win-installer/exaile-LATEST.exe dist/exaile-${DIST_VERSION}.exe
 
-gpg --armor --sign --detach-sig dist/exaile-${DIST_VERSION}.exe
\ No newline at end of file
+gpg --armor --sign --detach-sig dist/exaile-${DIST_VERSION}.exe
