@@ -43,6 +43,7 @@ logger = logging.getLogger(__name__)
 
 class NormalPlayer(_base.ExailePlayer):
     def __init__(self, name):
+        self._last_position = 0
         self._current = None
         self._buffered_track = None
         self._fakevideo = None
@@ -87,6 +88,7 @@ class NormalPlayer(_base.ExailePlayer):
             
 
     def _handle_message(self, bus, message, reading_tag = False):
+        
         if message.type == gst.MESSAGE_BUFFERING:
             percent = message.parse_buffering()
             if not percent < 100:
@@ -106,8 +108,49 @@ class NormalPlayer(_base.ExailePlayer):
         return True
 
     def _error_func(self):
+        
+        # No need to reinitialize more than once
+        if self._pipe.get_state(timeout=50*gst.MSECOND)[1] == gst.STATE_NULL:
+            return
+        
         self.stop()
         self._pipe.set_state(gst.STATE_NULL)
+        self._pipe.set_property('audio-sink', None)
+        
+        # The mainbin is still connected to the old element, need to
+        # disconnect it and flush it.
+        self._mainbin.unparent()
+        
+        # Only flush the element if necessary
+        if self._mainbin.get_state(timeout=50*gst.MSECOND)[1] != gst.STATE_NULL:
+        
+            # flush it
+            sinkpad = self._mainbin.get_static_pad('sink')
+            self._err_probe_id = sinkpad.add_event_probe(self._error_func_flush)
+            
+            sinkpad.send_event(gst.event_new_eos())
+            
+        else:
+            self._reinitialize()
+    
+    def _error_func_flush(self, pad, info):
+        
+        # wait for end of stream marker
+        if info.type != gst.EVENT_EOS:
+            return True
+        
+        pad.remove_event_probe(self._err_probe_id)
+        self._pad_event_probe_id = None
+        
+        # Finish clearing the element
+        self._mainbin.set_state(gst.STATE_NULL)    
+            
+        # Finally, reinitialize the pipe/bus now that the mainbin is ready
+        self._reinitialize()
+        
+        return False
+    
+    def _reinitialize(self):
         self._setup_pipe()
         self._setup_bus()
 
@@ -175,19 +218,24 @@ class NormalPlayer(_base.ExailePlayer):
         uri = track.get_loc_for_io()
         logger.info("Playing %s" % common.sanitize_url(uri))
         self._reset_playtime_stamp()
-
+        
         if not already_playing:
             self._pipe.set_property("uri", uri)
             if urlparse.urlsplit(uri)[0] == "cdda":
                 self.notify_id = self._pipe.connect('notify::source',
                         self.__notify_source)
-
-            self._pipe.set_state(gst.STATE_PLAYING)
             
+            self._pipe.set_state(gst.STATE_PLAYING)
+        
         if not playing:
             event.log_event('playback_player_start', self, track)
         event.log_event('playback_track_start', self, track)
-
+        
+        if playing and self._should_delay_start():
+            self._last_position = 0
+        
+        self._setup_startstop_offsets(track)
+        
         return True
         
     def play(self, track):
